/**
 * tdesign v1.9.3
 * (c) 2025 TDesign Group
 * @license MIT
 */

'use strict';

Object.defineProperty(exports, '__esModule', { value: true });

var _defineProperty = require('@babel/runtime/helpers/defineProperty');
var vue = require('vue');
var config = require('../config.js');
var grid_gridItemProps = require('./grid-item-props.js');
var hooks_tnode = require('../hooks/tnode.js');
var image_index = require('../image/index.js');
var badge_index = require('../badge/index.js');
var hooks_useClass = require('../hooks/useClass.js');
var shared_hover = require('../shared/hover.js');
var isString = require('../_chunks/dep-c3cb976c.js');
var isObject = require('../_chunks/dep-ef223206.js');
var isFunction = require('../_chunks/dep-88fe047a.js');
require('../hooks/render-tnode.js');
require('../_chunks/dep-a7319409.js');
require('../_chunks/dep-afa9f3f2.js');
require('../_chunks/dep-2f809ed9.js');
require('@babel/runtime/helpers/typeof');
require('../_chunks/dep-ae809b86.js');
require('../_chunks/dep-757b152c.js');
require('../_chunks/dep-2b08c0a6.js');
require('../_chunks/dep-5be9198d.js');
require('../_chunks/dep-288156c7.js');
require('../_chunks/dep-3d4c38f1.js');
require('../_chunks/dep-6df33aaf.js');
require('../_chunks/dep-675798b4.js');
require('../_chunks/dep-ccc9ad3d.js');
require('../_chunks/dep-d950aa21.js');
require('../_chunks/dep-a697b1b9.js');
require('../_chunks/dep-4dfb9b9c.js');
require('../_chunks/dep-7c911ba3.js');
require('../_common/js/utils/general.js');
require('../image/image.js');
require('@babel/runtime/helpers/slicedToArray');
require('@vueuse/core');
require('tdesign-icons-vue-next');
require('../loading/index.js');
require('../loading/loading.js');
require('../loading/icon/gradient.js');
require('../_common/js/loading/circle-adapter.js');
require('../_common/js/utils/setStyle.js');
require('../_common/js/utils/helper.js');
require('@babel/runtime/helpers/toConsumableArray');
require('@babel/runtime/helpers/objectWithoutProperties');
require('../_chunks/dep-6b5052db.js');
require('../_chunks/dep-f11711eb.js');
require('../_chunks/dep-ff4786c0.js');
require('../loading/icon/spinner.js');
require('../loading/props.js');
require('../shared/dom.js');
require('../loading/plugin.js');
require('../_chunks/dep-b9642a56.js');
require('../_common/js/global-config/mobile/default-config.js');
require('../_common/js/global-config/mobile/locale/zh_CN.js');
require('../_chunks/dep-28b1e09d.js');
require('../_chunks/dep-57aa1aa0.js');
require('dayjs');
require('../_chunks/dep-85204fa0.js');
require('../_chunks/dep-f6b14f80.js');
require('../_chunks/dep-a8d60643.js');
require('../_chunks/dep-49f0a63e.js');
require('../_chunks/dep-c65deed7.js');
require('../_chunks/dep-94eeec5a.js');
require('../_chunks/dep-060bf1cf.js');
require('../_chunks/dep-0e05e959.js');
require('../_chunks/dep-324da301.js');
require('../_chunks/dep-21f18d3b.js');
require('../_chunks/dep-da6dc2cf.js');
require('../shared/component.js');
require('../image/props.js');
require('../badge/badge.js');
require('../badge/props.js');

function _interopDefaultLegacy (e) { return e && typeof e === 'object' && 'default' in e ? e : { 'default': e }; }

var _defineProperty__default = /*#__PURE__*/_interopDefaultLegacy(_defineProperty);

function _isSlot(s) {
  return typeof s === 'function' || Object.prototype.toString.call(s) === '[object Object]' && !vue.isVNode(s);
}
var prefix = config["default"].prefix;
var _GridItem = vue.defineComponent({
  name: "".concat(prefix, "-grid-item"),
  directives: {
    Hover: shared_hover["default"]
  },
  components: {
    TImage: image_index.Image,
    TBadge: badge_index.Badge
  },
  props: grid_gridItemProps["default"],
  setup: function setup(props2, context) {
    var gridItemClass = hooks_useClass.usePrefixClass("grid-item");
    var renderTNodeJSX = hooks_tnode.useTNodeJSX();
    var _inject = vue.inject("grid"),
      column = _inject.column,
      border = _inject.border,
      align = _inject.align,
      gutter = _inject.gutter,
      hover = _inject.hover;
    var rootStyle = vue.computed(function () {
      var percent = column.value > 0 ? "".concat(100 / +column.value, "%") : 0;
      var style = {
        textAlign: ["center", "left"].includes(align.value) ? align.value : "center"
      };
      if (percent !== 0) {
        style.flexBasis = percent;
      }
      return style;
    });
    var size = vue.computed(function () {
      if (column.value > 4 || !column.value) return "small";
      return column.value < 4 ? "large" : "middle";
    });
    var realImage = vue.computed(function () {
      if (isString.isString(props2.image)) return {
        src: props2.image
      };
      if (isObject.isObject(props2.image) && !isFunction.isFunction(props2.image) && !context.slots.image) {
        return props2.image;
      }
      return null;
    });
    var gridItemClasses = vue.computed(function () {
      return ["".concat(gridItemClass.value), "".concat(gridItemClass.value, "--").concat(props2.layout), _defineProperty__default["default"](_defineProperty__default["default"]({}, "".concat(gridItemClass.value, "--bordered"), border.value), "".concat(gridItemClass.value, "--surround"), border.value && gutter.value)];
    });
    return function () {
      var _slot;
      var renderImage = function renderImage() {
        if (realImage.value) {
          return vue.createVNode(vue.resolveComponent("t-image"), vue.mergeProps({
            "shape": "round"
          }, realImage.value), null);
        }
        if (props2.icon) {
          return renderTNodeJSX("icon");
        }
        return renderTNodeJSX("image");
      };
      return vue.withDirectives(vue.createVNode("div", {
        "class": gridItemClasses.value,
        "style": rootStyle.value
      }, [vue.createVNode("div", {
        "class": "".concat(gridItemClass.value, "__image ").concat(gridItemClass.value, "__image--").concat(size.value)
      }, [props2.badge ? vue.createVNode(vue.resolveComponent("t-badge"), props2.badge, _isSlot(_slot = renderImage()) ? _slot : {
        default: function _default() {
          return [_slot];
        }
      }) : renderImage()]), vue.createVNode("div", {
        "class": "".concat(gridItemClass.value, "__content ").concat(gridItemClass.value, "__content--").concat(props2.layout)
      }, [vue.createVNode("div", {
        "class": "".concat(gridItemClass.value, "__title ").concat(gridItemClass.value, "__title--").concat(size.value)
      }, [renderTNodeJSX("text")]), vue.createVNode("div", {
        "class": "".concat(gridItemClass.value, "__description ").concat(gridItemClass.value, "__description--").concat(props2.layout)
      }, [renderTNodeJSX("description")])])]), [[vue.resolveDirective("hover"), {
        className: "".concat(gridItemClass.value, "--hover"),
        disabledHover: !hover.value
      }]]);
    };
  }
});

exports["default"] = _GridItem;
//# sourceMappingURL=grid-item.js.map
