/**
 * tdesign v1.9.3
 * (c) 2025 TDesign Group
 * @license MIT
 */

'use strict';

Object.defineProperty(exports, '__esModule', { value: true });

var _slicedToArray = require('@babel/runtime/helpers/slicedToArray');
var vue = require('vue');
var core = require('@vueuse/core');
var pullDownRefresh_props = require('./props.js');
var shared_dom = require('../shared/dom.js');
var config = require('../config.js');
var loading_index = require('../loading/index.js');
var hooks_useVModel = require('../hooks/useVModel.js');
var hooks_tnode = require('../hooks/tnode.js');
var pullDownRefresh_useTouch = require('./useTouch.js');
var hooks_useClass = require('../hooks/useClass.js');
var configProvider_useConfig = require('../_chunks/dep-21f18d3b.js');
var debounce = require('../_chunks/dep-f7e5ed5b.js');
var shared_util = require('../shared/util.js');
require('../_chunks/dep-88fe047a.js');
require('../_chunks/dep-2f809ed9.js');
require('@babel/runtime/helpers/typeof');
require('../_chunks/dep-ef223206.js');
require('../_chunks/dep-c3cb976c.js');
require('../_chunks/dep-757b152c.js');
require('../_chunks/dep-5be9198d.js');
require('../loading/loading.js');
require('@babel/runtime/helpers/defineProperty');
require('../loading/icon/gradient.js');
require('../_common/js/loading/circle-adapter.js');
require('../_common/js/utils/setStyle.js');
require('../_common/js/utils/helper.js');
require('@babel/runtime/helpers/toConsumableArray');
require('@babel/runtime/helpers/objectWithoutProperties');
require('../_chunks/dep-6b5052db.js');
require('../_chunks/dep-f11711eb.js');
require('../_chunks/dep-ff4786c0.js');
require('../loading/icon/spinner.js');
require('../loading/props.js');
require('../hooks/render-tnode.js');
require('../_chunks/dep-a7319409.js');
require('../_chunks/dep-afa9f3f2.js');
require('../_chunks/dep-ae809b86.js');
require('../_chunks/dep-2b08c0a6.js');
require('../_chunks/dep-288156c7.js');
require('../_chunks/dep-3d4c38f1.js');
require('../_chunks/dep-6df33aaf.js');
require('../_chunks/dep-675798b4.js');
require('../_chunks/dep-ccc9ad3d.js');
require('../_chunks/dep-d950aa21.js');
require('../_chunks/dep-a697b1b9.js');
require('../_chunks/dep-4dfb9b9c.js');
require('../_chunks/dep-7c911ba3.js');
require('../_common/js/utils/general.js');
require('../_chunks/dep-b9642a56.js');
require('../_common/js/global-config/mobile/default-config.js');
require('../_common/js/global-config/mobile/locale/zh_CN.js');
require('../_chunks/dep-28b1e09d.js');
require('../_chunks/dep-57aa1aa0.js');
require('dayjs');
require('../_chunks/dep-85204fa0.js');
require('../_chunks/dep-f6b14f80.js');
require('../_chunks/dep-a8d60643.js');
require('../_chunks/dep-49f0a63e.js');
require('../_chunks/dep-c65deed7.js');
require('../_chunks/dep-94eeec5a.js');
require('../_chunks/dep-060bf1cf.js');
require('../_chunks/dep-0e05e959.js');
require('../_chunks/dep-324da301.js');
require('../_chunks/dep-da6dc2cf.js');
require('../loading/plugin.js');
require('../shared/component.js');
require('../_chunks/dep-b7c281c3.js');

function _interopDefaultLegacy (e) { return e && typeof e === 'object' && 'default' in e ? e : { 'default': e }; }

var _slicedToArray__default = /*#__PURE__*/_interopDefaultLegacy(_slicedToArray);

var prefix = config["default"].prefix;
var statusName = ["pulling", "loosing", "loading", "success", "initial"];
var _PullDownRefresh = vue.defineComponent({
  name: "".concat(prefix, "-pull-down-refresh"),
  components: {
    TLoading: loading_index.Loading
  },
  props: pullDownRefresh_props["default"],
  emits: ["refresh", "timeout", "scrolltolower", "update:value", "update:modelValue"],
  setup: function setup(props) {
    var pullDownRefreshClass = hooks_useClass.usePrefixClass("pull-down-refresh");
    var _useConfig = configProvider_useConfig.useConfig("pullDownRefresh"),
      globalConfig = _useConfig.globalConfig;
    var renderContent = hooks_tnode.useContent();
    var timer = null;
    var distance = vue.ref(0);
    var afterLoading = vue.ref(false);
    var _toRefs = vue.toRefs(props),
      value = _toRefs.value,
      modelValue = _toRefs.modelValue;
    var _useVModel = hooks_useVModel["default"](value, modelValue, props.defaultValue, props.onChange),
      _useVModel2 = _slicedToArray__default["default"](_useVModel, 2),
      loading = _useVModel2[0],
      setLoading = _useVModel2[1];
    var loadingText = vue.computed(function () {
      var _props$loadingTexts;
      var index = statusName.indexOf(status.value);
      var loadingTexts = ((_props$loadingTexts = props.loadingTexts) === null || _props$loadingTexts === void 0 ? void 0 : _props$loadingTexts.length) > 0 ? props.loadingTexts : globalConfig.value.loadingTexts;
      return index >= 0 ? loadingTexts[index] : "";
    });
    var touch = pullDownRefresh_useTouch.useTouch();
    var loadingBar = vue.ref();
    var maxBar = vue.ref();
    var _useElementSize = core.useElementSize(loadingBar),
      loadingBarHeight = _useElementSize.height;
    var _useElementSize2 = core.useElementSize(maxBar),
      maxBarHeight = _useElementSize2.height;
    var actualLoadingBarHeight = vue.ref(0);
    var touchDir;
    var touchThreshold = 5;
    vue.watch([loading, loadingBarHeight], function (_ref, _ref2) {
      var _ref3 = _slicedToArray__default["default"](_ref, 1),
        val = _ref3[0];
      var _ref4 = _slicedToArray__default["default"](_ref2, 1),
        prevVal = _ref4[0];
      if (val) {
        distance.value = loadingBarHeight.value;
      }
      if (!val && prevVal) {
        afterLoading.value = true;
      }
    }, {
      immediate: true
    });
    var status = vue.computed(function () {
      if (afterLoading.value) {
        return "success";
      }
      if (!loading.value && distance.value === 0) {
        return "initial";
      }
      if (distance.value < loadingBarHeight.value) {
        return "pulling";
      }
      if (loading.value) {
        return "loading";
      }
      return "loosing";
    });
    vue.watch(status, function (newVal) {
      if (newVal === "success") {
        setTimeout(function () {
          distance.value = 0;
        }, 300);
      }
    });
    var isTouchable = function isTouchable() {
      return loading.value || props.disabled;
    };
    var onTouchStart = function onTouchStart(e) {
      if (isTouchable()) return;
      if (!pullDownRefresh_useTouch.isReachTop(e)) return;
      clearTimeout(timer);
      timer = null;
      distance.value = 0;
      touch.start(e);
      touchDir = 0;
    };
    var onTouchMove = function onTouchMove(e) {
      if (isTouchable()) return;
      if (!pullDownRefresh_useTouch.isReachTop(e)) return;
      touch.move(e);
      var diffY = touch.diffY,
        diffX = touch.diffX;
      var absX = Math.abs(diffX.value);
      var absY = Math.abs(diffY.value);
      if (!touchDir && absX < touchThreshold && absY < touchThreshold) {
        return;
      }
      if (!touchDir && absX < absY) {
        touchDir = -1;
      } else if (!touchDir && absX >= absY) {
        touchDir = 1;
      }
      if (touchDir === 1) return;
      actualLoadingBarHeight.value = diffY.value;
      var nextDistance = pullDownRefresh_useTouch.easeDistance(diffY.value, loadingBarHeight.value);
      if (diffY.value > 0) {
        shared_dom.preventDefault(e, false);
      }
      if (nextDistance >= 0 && nextDistance < maxBarHeight.value) {
        distance.value = nextDistance;
      }
    };
    var onTouchEnd = function onTouchEnd(e) {
      if (isTouchable()) return;
      if (!pullDownRefresh_useTouch.isReachTop(e)) return;
      if (status.value === "loosing") {
        var _props$onRefresh;
        distance.value = loadingBarHeight.value;
        setLoading(true);
        (_props$onRefresh = props.onRefresh) === null || _props$onRefresh === void 0 || _props$onRefresh.call(props);
        timer = setTimeout(function () {
          if (loading.value) {
            var _props$onTimeout;
            (_props$onTimeout = props.onTimeout) === null || _props$onTimeout === void 0 || _props$onTimeout.call(props);
            setLoading(false);
          }
        }, props.refreshTimeout);
      } else {
        distance.value = 0;
      }
    };
    var onReachBottom = debounce.debounce(function () {
      var scrollTop = document.documentElement.scrollTop || document.body.scrollTop;
      var _document$documentEle = document.documentElement,
        clientHeight = _document$documentEle.clientHeight,
        scrollHeight = _document$documentEle.scrollHeight;
      var distance2 = 20;
      if (scrollTop + clientHeight >= scrollHeight - distance2) {
        var _props$onScrolltolowe;
        (_props$onScrolltolowe = props.onScrolltolower) === null || _props$onScrolltolowe === void 0 || _props$onScrolltolowe.call(props);
      }
    }, 300, {
      leading: true,
      trailing: false
    });
    var onTransitionEnd = function onTransitionEnd() {
      if (afterLoading.value) {
        afterLoading.value = false;
      }
    };
    var trackStyle = vue.computed(function () {
      return {
        transform: "translate3d(0, ".concat(distance.value, "px, 0)")
      };
    });
    var heightDiff = (shared_util.reconvertUnit(props.maxBarHeight) - shared_util.reconvertUnit(props.loadingBarHeight)) / 2;
    var loadingBarStyles = vue.computed(function () {
      return {
        transform: "translateY(".concat(heightDiff, "px)"),
        height: "".concat(actualLoadingBarHeight.value, "px"),
        maxHeight: shared_util.convertUnit(props.loadingBarHeight)
      };
    });
    var maxBarStyles = vue.computed(function () {
      return {
        height: shared_util.convertUnit(props.maxBarHeight)
      };
    });
    vue.onMounted(function () {
      window.addEventListener("scroll", onReachBottom);
    });
    vue.onUnmounted(function () {
      clearTimeout(timer);
      window.removeEventListener("scroll", onReachBottom);
    });
    var renderLoading = function renderLoading() {
      if (status.value === "loading") {
        return vue.createVNode(vue.resolveComponent("t-loading"), vue.mergeProps({
          "size": "24px",
          "text": loadingText.value
        }, props.loadingProps), null);
      }
      return vue.createVNode("div", {
        "class": "".concat(pullDownRefreshClass.value, "__text")
      }, [loadingText.value]);
    };
    return function () {
      var content = renderContent("default", "content");
      var className = "".concat(pullDownRefreshClass.value, "__track");
      if (status.value !== "pulling") {
        className = "".concat(className, " ").concat(pullDownRefreshClass.value, "__track--loosing");
      }
      return vue.createVNode("div", {
        "class": pullDownRefreshClass.value
      }, [vue.createVNode("div", {
        "class": className,
        "style": trackStyle.value,
        "onTouchstart": onTouchStart,
        "onTouchmove": onTouchMove,
        "onTouchend": onTouchEnd,
        "onTouchcancel": onTouchEnd,
        "onTransitionend": onTransitionEnd
      }, [vue.createVNode("div", {
        "ref": maxBar,
        "class": "".concat(pullDownRefreshClass.value, "__tips"),
        "style": maxBarStyles.value
      }, [vue.createVNode("div", {
        "ref": loadingBar,
        "class": "".concat(pullDownRefreshClass.value, "__loading"),
        "style": loadingBarStyles.value
      }, [renderLoading()])]), content])]);
    };
  }
});

exports["default"] = _PullDownRefresh;
//# sourceMappingURL=pull-down-refresh.js.map
