/**
 * tdesign v1.9.3
 * (c) 2025 TDesign Group
 * @license MIT
 */

import { defineComponent, ref, onMounted, nextTick, onUpdated, createVNode } from 'vue';
import circleAdapter from '../../_common/js/loading/circle-adapter.mjs';
import config from '../../config.mjs';
import { usePrefixClass } from '../../hooks/useClass.mjs';
import '../../_chunks/dep-900db0e1.mjs';
import '../../_chunks/dep-4915223e.mjs';
import '../../_common/js/utils/setStyle.mjs';
import '../../_common/js/utils/helper.mjs';
import '../../_chunks/dep-fb4113ef.mjs';
import '../../_chunks/dep-a953013f.mjs';
import '../../_chunks/dep-da32ae58.mjs';
import '../../_chunks/dep-26b97ced.mjs';
import 'lodash-es';
import '../../config-provider/useConfig.mjs';
import '../../config-provider/context.mjs';
import '../../_common/js/global-config/mobile/default-config.mjs';
import '../../_common/js/global-config/mobile/locale/zh_CN.mjs';
import '../../_chunks/dep-bca0f578.mjs';
import '../../_chunks/dep-6b2b02fd.mjs';
import '../../_chunks/dep-c6f44a15.mjs';
import '../../_chunks/dep-c984d53e.mjs';
import '../../config-provider/type.mjs';

var prefix = config.prefix;
var TGradientIcon = defineComponent({
  name: "".concat(prefix, "-gradient"),
  props: {
    style: Object
  },
  setup: function setup(props) {
    var classPrefix = usePrefixClass();
    var gradientClass = usePrefixClass("loading__gradient");
    var classes = [gradientClass.value, "".concat(classPrefix.value, "-icon-loading")];
    var circle = ref();
    var updateColor = function updateColor() {
      var circleElem = circle.value;
      circleAdapter(circleElem);
    };
    onMounted(function () {
      nextTick(function () {
        updateColor();
      });
    });
    onUpdated(function () {
      updateColor();
    });
    return function () {
      return createVNode("svg", {
        "style": props.style,
        "class": classes,
        "viewBox": "0 0 12 12",
        "version": "1.1",
        "width": "1em",
        "height": "1em",
        "xmlns": "http://www.w3.org/2000/svg"
      }, [createVNode("foreignObject", {
        "x": "0",
        "y": "0",
        "width": "12",
        "height": "12"
      }, [createVNode("div", {
        "ref": circle,
        "class": "".concat(gradientClass.value, "-conic")
      }, null)])]);
    };
  }
});

export { TGradientIcon as default };
//# sourceMappingURL=gradient.mjs.map
