/**
 * tdesign v1.9.3
 * (c) 2025 TDesign Group
 * @license MIT
 */

import { _ as _defineProperty } from '../_chunks/dep-900db0e1.mjs';
import { defineComponent, ref, computed, h, createVNode } from 'vue';
import { LoadingIcon, CheckCircleIcon, ErrorCircleIcon, CloseCircleIcon } from 'tdesign-icons-vue-next';
import { useTNodeJSX, useContent } from '../hooks/tnode.mjs';
import { Overlay } from '../overlay/index.mjs';
import ToastProps from './props.mjs';
import config from '../config.mjs';
import { useLockScroll } from '../hooks/useLockScroll.mjs';
import { usePrefixClass } from '../hooks/useClass.mjs';
import '../_chunks/dep-4915223e.mjs';
import 'lodash-es';
import '../hooks/render-tnode.mjs';
import '../_common/js/utils/general.mjs';
import '../overlay/overlay.mjs';
import '../shared/dom.mjs';
import '../overlay/props.mjs';
import '../config-provider/useConfig.mjs';
import '../config-provider/context.mjs';
import '../_common/js/global-config/mobile/default-config.mjs';
import '../_common/js/global-config/mobile/locale/zh_CN.mjs';
import '../_chunks/dep-bca0f578.mjs';
import '../_chunks/dep-6b2b02fd.mjs';
import '../_chunks/dep-c6f44a15.mjs';
import '../_chunks/dep-c984d53e.mjs';
import '../config-provider/type.mjs';
import '../shared/index.mjs';
import '../shared/functions.mjs';
import '../shared/util.mjs';
import '../_chunks/dep-26b97ced.mjs';
import '../_chunks/dep-a953013f.mjs';
import '../shared/component.mjs';
import '../shared/render.mjs';
import '../shared/render-tnode.mjs';
import '../shared/useCountDown/index.mjs';
import '../_chunks/dep-99e43b7b.mjs';
import '@vueuse/core';
import '../shared/useCountDown/utils.mjs';
import '../shared/useTouch/index.mjs';
import '../shared/useScrollParent/index.mjs';
import '../shared/useTest/index.mjs';
import '../shared/useClickAway/index.mjs';
import '../_chunks/dep-fb4113ef.mjs';
import '../shared/hover.mjs';
import './style/css.mjs';
import '../_util/useTouch.mjs';
import '../_util/getScrollParent.mjs';

function ownKeys(e, r) { var t = Object.keys(e); if (Object.getOwnPropertySymbols) { var o = Object.getOwnPropertySymbols(e); r && (o = o.filter(function (r) { return Object.getOwnPropertyDescriptor(e, r).enumerable; })), t.push.apply(t, o); } return t; }
function _objectSpread(e) { for (var r = 1; r < arguments.length; r++) { var t = null != arguments[r] ? arguments[r] : {}; r % 2 ? ownKeys(Object(t), !0).forEach(function (r) { _defineProperty(e, r, t[r]); }) : Object.getOwnPropertyDescriptors ? Object.defineProperties(e, Object.getOwnPropertyDescriptors(t)) : ownKeys(Object(t)).forEach(function (r) { Object.defineProperty(e, r, Object.getOwnPropertyDescriptor(t, r)); }); } return e; }
var prefix = config.prefix;
var vueToast = defineComponent({
  name: "".concat(prefix, "-toast"),
  props: ToastProps,
  setup: function setup(props) {
    var toastTypeIcon = {
      loading: LoadingIcon,
      success: CheckCircleIcon,
      warning: ErrorCircleIcon,
      error: CloseCircleIcon
    };
    var toastClass = usePrefixClass("toast");
    var renderTNodeJSX = useTNodeJSX();
    var renderContent = useContent();
    var toastRef = ref();
    var customOverlayProps = computed(function () {
      var toastOverlayProps = {
        preventScrollThrough: props.preventScrollThrough,
        visible: props.showOverlay
      };
      return _objectSpread(_objectSpread({}, props.overlayProps), toastOverlayProps);
    });
    var classes = computed(function () {
      return ["".concat(toastClass.value), "".concat(toastClass.value, "__content"), "".concat(toastClass.value, "__icon"), _defineProperty(_defineProperty(_defineProperty({}, "".concat(toastClass.value, "--").concat(props.direction), props.direction), "".concat(toastClass.value, "__content--").concat(props.direction), props.direction), "".concat(toastClass.value, "--loading"), props.theme === "loading")];
    });
    var topOptions = {
      top: "25%",
      bottom: "75%",
      middle: "50%"
    };
    var computedStyle = computed(function () {
      return {
        top: topOptions[props.placement]
      };
    });
    var iconClasses = computed(function () {
      return [_defineProperty({}, "".concat(toastClass.value, "__icon--").concat(props.direction), props.direction)];
    });
    var iconContent = computed(function () {
      var iconNode = renderTNodeJSX("icon");
      if (iconNode === void 0 && props.theme) {
        iconNode = h(toastTypeIcon[props.theme]);
      }
      return iconNode;
    });
    var renderIconContent = computed(function () {
      if (iconContent.value) {
        return createVNode("div", {
          "class": iconClasses.value
        }, [iconContent.value]);
      }
      return "";
    });
    var textClasses = computed(function () {
      return [_defineProperty(_defineProperty({}, "".concat(toastClass.value, "__text"), !iconContent.value), "".concat(toastClass.value, "__text--").concat(props.direction), props.direction)];
    });
    var messageContent = computed(function () {
      return renderContent("default", "message");
    });
    var renderMessageContent = computed(function () {
      if (messageContent.value) {
        return createVNode("div", {
          "class": textClasses.value
        }, [messageContent.value]);
      }
      return "";
    });
    useLockScroll(toastRef, function () {
      return props.preventScrollThrough;
    }, toastClass.value);
    return function () {
      return createVNode("div", null, [createVNode(Overlay, customOverlayProps.value, null), createVNode("div", {
        "class": classes.value,
        "style": computedStyle.value
      }, [renderIconContent.value, renderMessageContent.value])]);
    };
  }
});

export { vueToast as default };
//# sourceMappingURL=toast.mjs.map
